==> haskell-charset-0.3.7.1-13-i686.pkg.tar.xz: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: charset
version: 0.3.7.1
id: charset-0.3.7.1-IQIZy6NlCuI6iyAvJEMNq8
key: charset-0.3.7.1-IQIZy6NlCuI6iyAvJEMNq8
license: BSD3
copyright: (c) Edward Kmett 2010-2012
maintainer: ekmett@gmail.com
stability: Experimental
homepage: http://github.com/ekmett/charset
synopsis: Fast unicode character sets based on complemented PATRICIA tries
description:
    Fast unicode character sets based on complemented PATRICIA tries
category: Data
author: Edward Kmett
exposed: True
exposed-modules:
    Data.CharSet Data.CharSet.Common Data.CharSet.Posix
    Data.CharSet.Posix.Ascii Data.CharSet.Posix.Unicode
    Data.CharSet.Unicode Data.CharSet.Unicode.Block
    Data.CharSet.Unicode.Category Data.CharSet.ByteSet
abi: eae92cb9875cfc3fcfb930f0c7cf2dfb
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/charset-0.3.7.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/charset-0.3.7.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/charset-0.3.7.1
hs-libraries: HScharset-0.3.7.1-IQIZy6NlCuI6iyAvJEMNq8
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
haddock-interfaces: /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html: /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-charset-0.3.7.1-15-i686.pkg.tar.xz: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: charset
version: 0.3.7.1
id: charset-0.3.7.1-64bxKwiao61GYFk7cH2T5U
key: charset-0.3.7.1-64bxKwiao61GYFk7cH2T5U
license: BSD3
copyright: (c) Edward Kmett 2010-2012
maintainer: ekmett@gmail.com
stability: Experimental
homepage: http://github.com/ekmett/charset
synopsis: Fast unicode character sets based on complemented PATRICIA tries
description:
    Fast unicode character sets based on complemented PATRICIA tries
category: Data
author: Edward Kmett
exposed: True
exposed-modules:
    Data.CharSet Data.CharSet.Common Data.CharSet.Posix
    Data.CharSet.Posix.Ascii Data.CharSet.Posix.Unicode
    Data.CharSet.Unicode Data.CharSet.Unicode.Block
    Data.CharSet.Unicode.Category Data.CharSet.ByteSet
abi: dd7325c324ccc7c21ed96d1c682b8747
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/charset-0.3.7.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/charset-0.3.7.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/charset-0.3.7.1
hs-libraries: HScharset-0.3.7.1-64bxKwiao61GYFk7cH2T5U
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
haddock-interfaces: /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html: /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
